<?php

namespace Combidesk\SnelStart;

class Application {
	
	private $title = '';
	private $menu_title = '';
	
	public function __construct() {
		$this->title = __('Combidesk - SnelStart voor WooCommerce', 'combidesk-snelstart');
		$this->menu_title = __('Combidesk - SnelStart', 'combidesk-snelstart');
		$this->run();
	}
	
	public function run() {
		add_action( 'admin_menu', [ $this, 'add_combidesk_page' ] );
		add_action( 'admin_enqueue_scripts', [ $this, 'load_combidesk_plugin_style' ] );
	}
	
	function add_combidesk_page() {
		$page_title = $this->title;
		$menu_title = $this->menu_title;
		$capability = 'manage_options';
		$menu_slug  = 'combidesk-snelstart-settings';
		$function   = [ $this, 'combidesk_settings' ];
		$icon_url   = 'data:image/svg+xml;base64,' . base64_encode('<svg width="10" height="10" viewBox="0 0 750 750" xmlns="http://www.w3.org/2000/svg">
		  <g stroke="null" id="XMLID_1_" fill="black" transform="translate(100,100)">
		   <path stroke="null" d="m332.53026,360.99324l0,236.96416l149.56391,0c63.83373,0 115.42029,-51.77212 115.42029,-115.42029l0,-149.56391l-236.77859,0c-15.58731,0 -28.2056,12.61829 -28.2056,28.02004z" class="st1" id="XMLID_570_"/>
		   <path stroke="null" d="m1.30002,597.9574l264.98419,0l0,-236.96416c0,-15.58731 -12.61829,-28.2056 -28.2056,-28.2056l-236.77859,0l0,265.16976z" class="st2" id="XMLID_567_"/>
		   <path stroke="null" d="m1.30002,117.16325l0,149.56391l236.96416,0c15.58731,0 28.2056,-12.61829 28.2056,-28.2056l0,-236.77859l-149.56391,0c-63.83373,0 -115.60585,51.77212 -115.60585,115.42029z" class="st3" id="XMLID_564_"/>
		   <path stroke="null" d="m332.53026,1.74296l0,236.96416c0,15.58731 12.61829,28.2056 28.2056,28.2056l236.96416,0l0,-265.16976l-265.16976,0z" class="st4" id="XMLID_561_"/>
		  </g>
		  </svg>');
		$position   = 4;
		
		add_menu_page( $page_title,
			$menu_title,
			$capability,
			$menu_slug,
			$function,
			$icon_url,
			$position );
	}
	
	// Create Dashboard plugin page
	function combidesk_settings() {
		$current_user = wp_get_current_user();
		
		$email_address = (string) $current_user->user_email;
		
		echo '
		  <h1>' . $this->title . '</h1>
			'.__('Deze koppeling wisselt automatisch belangrijke gegevens uit tussen WooCommerce en SnelStart. Dit bespaart tijd, je hoeft nooit meer dubbel werk te verrichten én je maakt minder fouten. Er is immers geen handwerk meer nodig.', 'combidesk-snelstart').'
			<br><br>
			<h2>'.__('Belangrijkste kenmerken', 'combidesk-snelstart').'</h2>
			<ul>
				<li>'.__('Deze koppeling wordt iedere 15-30 minuten (meestal eerder) gesynchroniseerd.', 'combidesk-snelstart').'</li>
				<li>'.__('Afgeronde orders worden overgezet vanaf het moment van installatie.', 'combidesk-snelstart').'</li>
				<li>'.__('Orderhistorie kan automatisch worden meegenomen.', 'combidesk-snelstart').'</li>
				<li>'.__('Klanten worden op basis van een uniek e-mailadres aangemaakt in SnelStart.', 'combidesk-snelstart').'</li>
				<li>'.__('Gebruik SnelStart als betaalbaar en eenvoudig boekhoudpakket. Wij adviseren om de facturatie vanuit WooCommerce te laten verlopen.', 'combidesk-snelstart').'</li>
			</ul>
		  <br><br>
		  
		  <form class="combidesk__cta-form" action="https://combidesk.com/combipackageinstall/woocommerce-snelstart " method="GET" target="_BLANK">
			<input type="hidden" name="email_address" value="' . $email_address . '" />
			<input type="submit" value="'.__('Begin met koppelen', 'combidesk-snelstart').'" />
		  </form>
		  
		  <form class="combidesk__cta-form" action="https://www.snelstart.nl/tijdbesparen/v2" method="GET" target="_BLANK">
			<input type="hidden" name="utm_source" value="combidesk" />
			<input type="hidden" name="utm_medium" value="referral" />
			<input type="hidden" name="utm_campaign" value="tijdbesparen" />
			<input type="hidden" name="utm_term" value="combidesk_cta" />
			<input type="hidden" name="email_address" value="' . $email_address . '" />
			<input type="submit" value="'.__('Nog geen SnelStart account?', 'combidesk-snelstart').'" />
		  </form>';
		
		echo '
		<script>
		  window.intercomSettings = {
			app_id: "vyxefwdz"
		  };
		</script>
		
		<script>
		// We pre-filled your app ID in the widget URL: \'https://widget.intercom.io/widget/vyxefwdz\'
		(function(){var w=window;var ic=w.Intercom;if(typeof ic==="function"){ic(\'reattach_activator\');ic(\'update\',w.intercomSettings);}else{var d=document;var i=function(){i.c(arguments);};i.q=[];i.c=function(args){i.q.push(args);};w.Intercom=i;var l=function(){var s=d.createElement(\'script\');s.type=\'text/javascript\';s.async=true;s.src=\'https://widget.intercom.io/widget/vyxefwdz\';var x=d.getElementsByTagName(\'script\')[0];x.parentNode.insertBefore(s,x);};if(w.attachEvent){w.attachEvent(\'onload\',l);}else{w.addEventListener(\'load\',l,false);}}})();
		</script>';
	}
	
	function load_combidesk_plugin_style($hook) {
		if ($hook != 'toplevel_page_combidesk-snelstart-settings') {
			return;
		}
		
		wp_enqueue_style( 'custom_wp_admin_css', plugins_url('../assets/css/combidesk.min.css', __FILE__) );
	}
}
